@@ -2,7 +2,9 @@
 #' 
 #' @description The function calculates a dissimilarity matrix based on the VE similarity measure.
 #'  
-#' @param data A data.frame or a matrix with cases in rows and variables in colums.
+#' @param data A data.frame or a matrix with cases in rows and variables in columns.
+#' 
+#' @param var.weights A numeric vector setting weights to the used variables. One can choose the real numbers from zero to one.
 #' 
 #' @return The function returns an object of the class "dist".
 #' \cr
@@ -20,16 +22,24 @@
 #'  
 #'  
 #' @seealso
+#' \code{\link[nomclust]{anderberg}},
+#' \code{\link[nomclust]{burnaby}},
 #' \code{\link[nomclust]{eskin}},
+#' \code{\link[nomclust]{gambaryan}},
 #' \code{\link[nomclust]{good1}},
+#' \code{\link[nomclust]{goodall1}},
 #' \code{\link[nomclust]{good2}},
+#' \code{\link[nomclust]{goodall2}},
 #' \code{\link[nomclust]{good3}},
+#' \code{\link[nomclust]{goodall3}},
 #' \code{\link[nomclust]{good4}},
+#' \code{\link[nomclust]{goodall4}},
 #' \code{\link[nomclust]{iof}},
 #' \code{\link[nomclust]{lin}},
 #' \code{\link[nomclust]{lin1}},
 #' \code{\link[nomclust]{of}},
 #' \code{\link[nomclust]{sm}},
+#' \code{\link[nomclust]{smirnov}},
 #' \code{\link[nomclust]{vm}}.
 #'
 #' @author Zdenek Sulc. \cr Contact: \email{zdenek.sulc@@vse.cz}
@@ -41,9 +51,15 @@
 #' # dissimilarity matrix calculation
 #' prox.ve <- ve(data20)
 #' 
+#' # dissimilarity matrix calculation with variable weighting
+#' prox.ve.2 <- ve(data20, var.weights = c(1, 0.8, 0.6, 0.4, 0.2))
+#' 
+#' # dissimilarity matrix calculation with variable weights
+#' weights.ve <- ve(data20, var.weights = c(0.7, 1, 0.9, 0.5, 0))
+#' 
 #' @export 
 
-ve <- function(data) {
+ve <- function(data, var.weights = NULL) {
   
   # dealing with the missing data
   if (sum(is.na(data)) > 0) {
@@ -63,19 +79,18 @@ ve <- function(data) {
   #   var.wgt <- WGT(data, var.weights, alpha)
   
   # OWN-DEFINED WEIGHTS
-  # } else if (is.numeric(var.weights) == TRUE) {
-  #    if(is.na(sum(var.weights >= 0)) | sum(var.weights >= 0)!=ncol(data)) {
-  #     stop("The vector of weights contains negative or missing values.")
-  #  }
-  #    var.wgt <- var.weights
+  if (is.null(var.weights) == TRUE) {
+    var.weights <- rep(1, ncol(data))
+  } else if (!(is.numeric(var.weights) & length(var.weights) == ncol(data))) {
+    stop("The weight vector should be numeric with the length equal to the number of clustered variables.")
+  } else if (!(range(var.weights)[1] >= 0 & range(var.weights)[2] <= 1)) {
+    stop("The weight vector should contain values in a range from zero to one.")
+  }
   
   
-  # } else {
-  #   stop("Invalid weighting scheme.")
-  # }
   freq.table <- freq.abs(data)
   
-  prox_matrix <- SIMILARITY(data, measure = "ve", freq.table)
+  prox_matrix <- SIMILARITY(data, measure = "ve", freq.table, wt = var.weights)
   
   row.names(prox_matrix) <- rnames
   
